## cdist-type__cdist(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__cdist - Manage cdist installations

## 2. DESCRIPTION

This cdist type allows you to easily setup cdist on another box, to allow the other box to configure systems.

This type is NOT required by target hosts. It is only helpful to build FROM which you configure other hosts.

This type will use git to clone

## 3. REQUIRED PARAMETERS

## 4. OPTIONAL PARAMETERS

username
  Select the user to create for the cdist installation. Defaults to "cdist".
source
  Select the source from which to clone cdist from. Defaults to "git://github.com/telmich/cdist.git".
branch
  Select the branch to checkout from. Defaults to "master".

## 5. EXAMPLES

    # Install cdist for user cdist in her home as subfolder cdist
    __cdist /home/cdist/cdist

    # Use alternative source
    __cdist --source "git://git.schottelius.org/cdist" /home/cdist/cdist

## 6. SEE ALSO

- cdist-type(7)

## 7. COPYING

Copyright (C) 2013 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).